@@ -43,31 +43,6 @@ ge_blend_color(const CairoColor *color1, const CairoColor *color2, CairoColor *c
 	composite->a = (color1->a + color2->a)/2;	
 }
 
-void
-ge_cairo_pattern_add_color_stop(cairo_pattern_t *pattern, gdouble offset, CairoColor *color)
-{
-	g_return_if_fail (pattern && color);
-	
-	cairo_pattern_add_color_stop_rgba(pattern, offset, color->r, color->g, color->b, color->a);	
-}
-
-void
-ge_cairo_pattern_add_shade_color_stop(cairo_pattern_t *pattern, gdouble offset, CairoColor *color, gdouble shade)
-{
-	CairoColor shaded;
-
-	g_return_if_fail (pattern && color && (shade >= 0) && (shade <= 3));
-
-	shaded = *color;
-
-	if (shade != 1)
-	{
-		ge_shade_color(color, shade, &shaded);
-	}
-
-	cairo_pattern_add_color_stop_rgba(pattern, offset, shaded.r, shaded.g, shaded.b, shaded.a);	
-}
-
 typedef struct 
 {
 	cairo_path_t *clip;
@@ -76,74 +51,6 @@ typedef struct
 	cairo_pattern_t **layers;
 } GlideFill;
 
-void glide_draw_pattern_fill(cairo_t *canvas,
-					CairoPattern *pattern,
-					gint x,
-					gint y,
-					gint width,
-					gint height)
-{
-	cairo_matrix_t original_matrix, current_matrix;
-
-	if (pattern->operator == CAIRO_OPERATOR_DEST)
-	{
-		return;
-	}
-
-	cairo_pattern_get_matrix(pattern->handle, &original_matrix);
-	current_matrix = original_matrix;
-
-	if (pattern->scale != GLIDE_DIRECTION_NONE)
-	{
-		gdouble scale_x = 1.0;
-		gdouble scale_y = 1.0;
-
-		if ((pattern->scale == GLIDE_DIRECTION_VERTICAL) || (pattern->scale == GLIDE_DIRECTION_BOTH))
-		{
-			scale_x = 1.0/width;
-		}
-
-		if ((pattern->scale == GLIDE_DIRECTION_HORIZONTAL) || (pattern->scale == GLIDE_DIRECTION_BOTH))
-		{
-			scale_y = 1.0/height;
-		}
-
-		cairo_matrix_scale(&current_matrix, scale_x, scale_y);
-	}
-
-	if (pattern->translate != GLIDE_DIRECTION_NONE)
-	{
-		gdouble translate_x = 0;
-		gdouble translate_y = 0;
-
-		if ((pattern->translate == GLIDE_DIRECTION_VERTICAL) || (pattern->translate == GLIDE_DIRECTION_BOTH))
-		{
-			translate_x = 0.0-x;
-		}
-
-		if ((pattern->translate == GLIDE_DIRECTION_HORIZONTAL) || (pattern->translate == GLIDE_DIRECTION_BOTH))
-		{
-			translate_y = 0.0-y;
-		}
-
-		cairo_matrix_translate(&current_matrix, translate_x, translate_y);
-	}
-
-	cairo_pattern_set_matrix(pattern->handle, &current_matrix);
-
-	cairo_save(canvas);
-
-	cairo_set_source(canvas, pattern->handle);
-        cairo_set_operator(canvas, pattern->operator);
-	cairo_rectangle(canvas, x, y, width, height);
-
-	cairo_fill (canvas);
-
-	cairo_restore(canvas);
-
-	cairo_pattern_set_matrix(pattern->handle, &original_matrix);
-}
-
 static void 
 glide_simple_border_gap_clip(cairo_t *canvas,
 				gint x,
@@ -481,7 +388,7 @@ do_glide_draw_option_check(cairo_t *canvas,
 	{
 		case GLIDE_CHECK_ON:
 		{
-			cairo_arc(canvas, center_x, center_y, radius*0.68, 0, 2 * M_PI);
+			cairo_arc(canvas, center_x, center_y, radius*0.68, 0, 2 * G_PI);
 			cairo_fill(canvas);
 		}
 		break;
@@ -539,7 +446,7 @@ do_glide_draw_round_option(cairo_t *canvas,
 		|| (bevel_style == GLIDE_BEVEL_STYLE_NONE)) 
 	{
 		ge_cairo_set_color(canvas, fill_color);
-		cairo_arc(canvas, center_x, center_y, radius, 0, 2 * M_PI);
+		cairo_arc(canvas, center_x, center_y, radius, 0, 2 * G_PI);
 		cairo_fill(canvas);
 
 		do_glide_draw_option_check(canvas, check_color, check_state, center_x, center_y, radius - 1);
@@ -557,7 +464,7 @@ do_glide_draw_round_option(cairo_t *canvas,
 						center_x, center_y, radius);
 
 		ge_cairo_set_color(canvas, fill_color);
-		cairo_arc(canvas, center_x, center_y, radius - 1, 0, 2 * M_PI);
+		cairo_arc(canvas, center_x, center_y, radius - 1, 0, 2 * G_PI);
 		cairo_fill(canvas);
 
 		do_glide_draw_option_check(canvas, check_color, check_state, center_x, center_y, radius - 2);
@@ -597,7 +504,7 @@ do_glide_draw_round_option(cairo_t *canvas,
 								center_x, center_y, radius - 1);		
 
 			ge_cairo_set_color(canvas, fill_color);
-			cairo_arc(canvas, center_x, center_y, radius - 2, 0, 2 * M_PI);
+			cairo_arc(canvas, center_x, center_y, radius - 2, 0, 2 * G_PI);
 			cairo_fill(canvas);
 
 			do_glide_draw_option_check(canvas, check_color, check_state, center_x, center_y, radius - 3);
@@ -627,7 +534,7 @@ do_glide_draw_round_option(cairo_t *canvas,
 								center_x, center_y, radius);
 
 				ge_cairo_set_color(canvas, fill_color);
-				cairo_arc(canvas, center_x, center_y, radius - 1, 0, 2 * M_PI);
+				cairo_arc(canvas, center_x, center_y, radius - 1, 0, 2 * G_PI);
 				cairo_fill(canvas);
 
 				do_glide_draw_option_check(canvas, check_color, check_state, center_x, center_y, radius - 2);
@@ -702,7 +609,7 @@ do_glide_draw_round_option(cairo_t *canvas,
 								center_x, center_y, radius - 1);
 
 				ge_cairo_set_color(canvas, fill_color);
-				cairo_arc(canvas, center_x, center_y, radius - 2, 0, 2 * M_PI);
+				cairo_arc(canvas, center_x, center_y, radius - 2, 0, 2 * G_PI);
 				cairo_fill(canvas);
 
 				do_glide_draw_option_check(canvas, check_color, check_state, center_x, center_y, radius - 3);
@@ -733,29 +640,6 @@ do_glide_draw_check (cairo_t *canvas,
                        gint width, 
                        gint height)
 { 
-  gint odd = 0;
-  gdouble left, top;
-  gint scale, factor;
-
-  scale = MIN(width, height);
-
-  factor = 10;
-
-  if ((odd = (scale % 2)))
-  {
-    factor -= 1;
-  }
-
-  if (scale <= (factor + 2))
-    scale = factor;
-
-  left = x + floor((width - scale) / 2) + 0.5;
-  top = y + floor((height - scale) / 2) + 0.5;
-
-  cairo_save(canvas);
-
-  ge_cairo_set_color(canvas, color);	
-  cairo_set_line_width(canvas, 0.5);
 /*
 
 EVEN - 
@@ -807,6 +691,29 @@ ODD -
   +---+---+---+---+---+---+---+---+---+
 
 */
+  gint odd = 0;
+  gdouble left, top;
+  gint scale, factor;
+
+  scale = MIN(width, height);
+
+  factor = 10;
+
+  if ((odd = (scale % 2)))
+  {
+    factor -= 1;
+  }
+
+  if (scale <= (factor + 2))
+    scale = factor;
+
+  left = x + floor((width - scale) / 2) + 0.5;
+  top = y + floor((height - scale) / 2) + 0.5;
+
+  cairo_save(canvas);
+
+  ge_cairo_set_color(canvas, color);	
+  cairo_set_line_width(canvas, 0.5);
 
   cairo_move_to(canvas, left + floor((1*scale)/factor), top + floor(((4-odd)*scale)/factor)); /*(1,4-odd)*/
   cairo_line_to(canvas, left + floor((1*scale)/factor), top + floor(((6-odd)*scale)/factor)); /*(1,6-odd)*/
@@ -833,8 +740,8 @@ do_glide_draw_simple_circle (cairo_t *canvas,
       cairo_new_path (canvas);
 
       cairo_move_to(canvas, center_x + (radius + 2), center_y + (radius + 2));
-      cairo_line_to(canvas, center_x + (radius + 2)*sin(M_PI/4.0), center_y - (radius + 2)*cos(M_PI/4.0));
-      cairo_line_to(canvas, center_x - (radius + 2)*sin(M_PI/4.0), center_y + (radius + 2)*cos(M_PI/4.0));
+      cairo_line_to(canvas, center_x + (radius + 2)*sin(G_PI/4.0), center_y - (radius + 2)*cos(G_PI/4.0));
+      cairo_line_to(canvas, center_x - (radius + 2)*sin(G_PI/4.0), center_y + (radius + 2)*cos(G_PI/4.0));
       cairo_line_to(canvas, center_x + (radius + 2), center_y + (radius + 2));
 
       cairo_close_path (canvas);
@@ -844,7 +751,7 @@ do_glide_draw_simple_circle (cairo_t *canvas,
       cairo_clip (canvas);
 
       ge_cairo_set_color(canvas, br);
-      cairo_arc(canvas, center_x, center_y, radius, 0,  2*M_PI);
+      cairo_arc(canvas, center_x, center_y, radius, 0,  2*G_PI);
       cairo_fill(canvas);
 
       cairo_restore(canvas);
@@ -853,8 +760,8 @@ do_glide_draw_simple_circle (cairo_t *canvas,
       cairo_new_path (canvas);
 
       cairo_move_to(canvas, center_x - (radius + 2), center_y - (radius + 2));
-      cairo_line_to(canvas, center_x + (radius + 2)*sin(M_PI/4.0), center_y - (radius + 2)*cos(M_PI/4.0));
-      cairo_line_to(canvas, center_x - (radius + 2)*sin(M_PI/4.0), center_y + (radius + 2)*cos(M_PI/4.0));
+      cairo_line_to(canvas, center_x + (radius + 2)*sin(G_PI/4.0), center_y - (radius + 2)*cos(G_PI/4.0));
+      cairo_line_to(canvas, center_x - (radius + 2)*sin(G_PI/4.0), center_y + (radius + 2)*cos(G_PI/4.0));
       cairo_line_to(canvas, center_x - (radius + 2), center_y - (radius + 2));
 
       cairo_close_path (canvas);
@@ -862,7 +769,7 @@ do_glide_draw_simple_circle (cairo_t *canvas,
       cairo_clip (canvas);
 
       ge_cairo_set_color(canvas, tl); 
-      cairo_arc(canvas, center_x, center_y, radius, 0, 2*M_PI);
+      cairo_arc(canvas, center_x, center_y, radius, 0, 2*G_PI);
       cairo_fill(canvas);
 
       cairo_restore(canvas);
@@ -1063,36 +970,26 @@ static void
 do_glide_draw_dot (cairo_t *canvas,
 			CairoColor * light,
 			CairoColor * dark,
+			CairoColor * mid,
 			gint x,
 			gint y)
 {
-	CairoColor mid;
-
-	cairo_save(canvas);
-
-	cairo_set_line_width (canvas, 0.5);
-	cairo_set_antialias(canvas, CAIRO_ANTIALIAS_NONE);
-
 	ge_cairo_set_color(canvas, dark);	
-	cairo_rectangle (canvas, x - 1, y, 0.5, 0.5);
-	cairo_rectangle (canvas, x - 1, y - 1, 0.5, 0.5);
-	cairo_rectangle (canvas, x, y - 1, 0.5, 0.5);
-	cairo_stroke(canvas);
+	cairo_rectangle (canvas, x - 1, y - 1, 1, 1);
+	cairo_rectangle (canvas, x - 0, y - 1, 1, 1);
+	cairo_rectangle (canvas, x - 1, y - 0, 1, 1);
+	cairo_fill(canvas);
 
 	ge_cairo_set_color(canvas, light);	
-	cairo_rectangle (canvas, x + 1, y, 0.5, 0.5);
-	cairo_rectangle (canvas, x + 1, y + 1, 0.5, 0.5);
-	cairo_rectangle (canvas, x, y + 1, 0.5, 0.5);
-	cairo_stroke(canvas);
+	cairo_rectangle (canvas, x + 1, y + 1, 1, 1);
+	cairo_rectangle (canvas, x + 0, y + 1, 1, 1);
+	cairo_rectangle (canvas, x + 1, y + 0, 1, 1);
+	cairo_fill(canvas);
 
-	ge_blend_color(dark, light, &mid);	
-
-	ge_cairo_set_color(canvas, &mid);	
-	cairo_rectangle (canvas, x + 1, y - 1, 0.5, 0.5);
-	cairo_rectangle (canvas, x - 1, y + 1, 0.5, 0.5);
-	cairo_stroke(canvas);
-
-	cairo_restore(canvas);
+	ge_cairo_set_color(canvas, mid);	
+	cairo_rectangle (canvas, x + 1, y - 1, 1, 1);
+	cairo_rectangle (canvas, x - 1, y + 1, 1, 1);
+	cairo_fill(canvas);
 }
 
 void
@@ -1106,24 +1003,34 @@ do_glide_draw_grip (cairo_t *canvas,
 			gboolean vertical)
 {
 	gint modx=0, mody=0;
+	CairoColor mid;
 	
 	if (vertical) 
 		mody = 5; 
 	else
 		modx = 5;
 	
+	cairo_save(canvas);
+
+	cairo_set_line_width (canvas, 0.5);
+	cairo_set_antialias(canvas, CAIRO_ANTIALIAS_NONE);
+
+	ge_blend_color(dark, light, &mid);	
+
 	do_glide_draw_dot (canvas,
-		 light, dark,
+		 light, dark, &mid,
 		 x + width / 2 - modx + 1,
 		 y + height / 2 - mody);
 	do_glide_draw_dot (canvas,
-		 light, dark,
+		 light, dark, &mid,
 		 x + width / 2 + 1,
 		 y + height / 2);
 	do_glide_draw_dot (canvas,
-		 light, dark,
+		 light, dark, &mid,
 		 x + width / 2 + modx + 1,
 		 y + height / 2 + mody);
+
+	cairo_restore(canvas);
 }
 
 /***********************************************/
@@ -1138,7 +1045,7 @@ do_glide_draw_grip (cairo_t *canvas,
 static void
 glide_gtk2_engine_hack_menu_shell_cleanup(GtkWidget *widget)
 {
-  if (IS_MENU_BAR(widget))
+  if (GE_IS_MENU_BAR(widget))
     {
       gint id = 0;
  
@@ -1201,7 +1108,7 @@ glide_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
                       GdkEventMotion *event, 
                       gpointer user_data)
 {
-  if (IS_MENU_SHELL(widget))
+  if (GE_IS_MENU_SHELL(widget))
     {
       gint pointer_x, pointer_y;
       GdkModifierType pointer_mask;
@@ -1209,13 +1116,13 @@ glide_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
      
       gdk_window_get_pointer(widget->window, &pointer_x, &pointer_y, &pointer_mask);
 	    
-      if (IS_CONTAINER(widget))
+      if (GE_IS_CONTAINER(widget))
         {
           children = gtk_container_get_children(GTK_CONTAINER(widget));
               
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
-	      if ((child->data) && IS_WIDGET(child->data) && 
+	      if ((child->data) && GE_IS_WIDGET(child->data) && 
                   (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
 	          if ((pointer_x >= GTK_WIDGET(child->data)->allocation.x) && 
@@ -1253,20 +1160,20 @@ glide_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget,
                       GdkEventCrossing *event,
                       gpointer user_data)
 {
-  if (IS_MENU_SHELL(widget))
+  if (GE_IS_MENU_SHELL(widget))
     {
       GList *children = NULL, *child = NULL;
  
-      if (IS_CONTAINER(widget))
+      if (GE_IS_CONTAINER(widget))
         {
           children = gtk_container_get_children(GTK_CONTAINER(widget));
               
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
-	      if ((child->data) && IS_MENU_ITEM(child->data) && 
+	      if ((child->data) && GE_IS_MENU_ITEM(child->data) && 
                   (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
-                  if ((!GTK_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
+                  if ((!GE_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
                       (!(GTK_WIDGET_REALIZED(GTK_MENU_ITEM(child->data)->submenu) && 
                          GTK_WIDGET_VISIBLE(GTK_MENU_ITEM(child->data)->submenu) &&
                          GTK_WIDGET_REALIZED(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel) &&
@@ -1294,7 +1201,7 @@ glide_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget,
 void
 glide_gtk2_engine_hack_menu_shell_setup(GtkWidget *widget)
 {
-  if (IS_MENU_BAR(widget))
+  if (GE_IS_MENU_BAR(widget))
     {
       gint id = 0;
  
