@@ -56,129 +56,17 @@ mist_dot (cairo_t *cr,
 	  int x,
 	  int y)
 {
-	cairo_save(cr);
+	ge_cairo_set_color (cr, color1);
+	cairo_rectangle (cr, x + 1, y + 1, 1, 1);
+	cairo_rectangle (cr, x + 1, y, 1, 1);
+	cairo_rectangle (cr, x, y + 1, 1, 1);
+	cairo_fill (cr);
 
-	cairo_set_line_width (cr, 0.5);
-	cairo_set_antialias(cr, CAIRO_ANTIALIAS_NONE);
-
-	ge_cairo_set_color(cr, color2);	
-
-	cairo_rectangle (cr, x - 1, y, 0.5, 0.5);
-	cairo_rectangle (cr, x - 1, y - 1, 0.5, 0.5);
-	cairo_rectangle (cr, x, y - 1, 0.5, 0.5);
-
-	cairo_stroke(cr);
-	
-	ge_cairo_set_color(cr, color1);	
-
-	cairo_rectangle (cr, x + 1, y, 0.5, 0.5);
-	cairo_rectangle (cr, x + 1, y + 1, 0.5, 0.5);
-	cairo_rectangle (cr, x, y + 1, 0.5, 0.5);
-
-	cairo_stroke(cr);
-
-	cairo_restore(cr);
-}
-
-static void
-mist_tab (GtkStyle *style,
-	  GdkWindow *window,
-	  GtkStateType state_type,
-	  GtkShadowType shadow_type,
-	  GdkRectangle *area,
-	  GtkWidget *widget,
-	  const char *detail,
-	  int x,
-	  int y,
-	  int width,
-	  int height,
-	  GtkPositionType gap_side)
-{
-	MistStyle *mist_style = MIST_STYLE (style);
-
-	cairo_t *cr;
-	CairoColor *light, *dark;
-		
-	cr = ge_gdk_drawable_to_cairo (window, area);
-
-	if ((!style->bg_pixmap[state_type]) || GDK_IS_PIXMAP(window)) 
-	{
-		ge_cairo_set_color(cr, &mist_style->color_cube.bg[state_type]);	
-
-		cairo_rectangle(cr, x, y, width, height);
-		cairo_fill(cr);
-	} else {
-		gtk_style_apply_default_background
-			(style, window,
-			 widget && !GTK_WIDGET_NO_WINDOW(widget),
-			 state_type, area, x, y, width, height);
-	}
-	
-	light = &mist_style->color_cube.light[state_type];
-	dark = &mist_style->color_cube.dark[state_type];
-
-	switch(gap_side) {
-	case GTK_POS_BOTTOM:
-		ge_cairo_set_color(cr, light);	
-	
-		cairo_move_to (cr, x + 0.5, y + height - 0.5);
-		cairo_line_to (cr, x + 0.5, y + 0.5);
-		cairo_line_to (cr, x + width - 0.5, y + 0.5);
-		cairo_stroke (cr);
-
-		ge_cairo_set_color(cr, dark);	
-	
-		cairo_move_to (cr, x + width - 0.5, y + 0.5);
-		cairo_line_to (cr, x + width - 0.5, y + height - 0.5);
-		cairo_stroke (cr);
-
-		break;
-	case GTK_POS_TOP:
-		ge_cairo_set_color(cr, light);	
-	
-		cairo_move_to (cr, x + 0.5, y + 0.5);
-		cairo_line_to (cr, x + 0.5, y + height - 0.5);
-		cairo_stroke (cr);
-
-		ge_cairo_set_color(cr, dark);	
-	
-		cairo_move_to (cr, x + 0.5, y + height - 0.5);
-		cairo_line_to (cr, x + width - 0.5, y + height - 0.5);
-		cairo_line_to (cr, x + width - 0.5, y + 0.5);
-		cairo_stroke (cr);
-		break;
-	case GTK_POS_RIGHT:
-		ge_cairo_set_color(cr, light);	
-	
-		cairo_move_to (cr, x + 0.5, y + height - 0.5);
-		cairo_line_to (cr, x + 0.5, y + 0.5);
-		cairo_line_to (cr, x + width - 0.5, y + 0.5);
-		cairo_stroke (cr);
-
-		ge_cairo_set_color(cr, dark);	
-	
-		cairo_move_to (cr, x + 0.5, y + height - 0.5);
-		cairo_line_to (cr, x + width - 0.5, y + height - 0.5);
-		cairo_stroke (cr);
-
-		break;
-	case GTK_POS_LEFT:
-		ge_cairo_set_color(cr, light);	
-	
-		cairo_move_to (cr, x + 0.5, y + 0.5);
-		cairo_line_to (cr, x + width - 0.5, y + 0.5);
-		cairo_stroke (cr);
-
-		ge_cairo_set_color(cr, dark);	
-	
-		cairo_move_to (cr, x + width - 0.5, y + 0.5);
-		cairo_line_to (cr, x + width - 0.5, y + height - 0.5);
-		cairo_line_to (cr, x + 0.5, y + height - 0.5);
-		cairo_stroke (cr);
-		break;
-	}
-
-	cairo_destroy(cr);
+	ge_cairo_set_color (cr, color2);
+	cairo_rectangle (cr, x - 1, y - 1, 1, 1);
+	cairo_rectangle (cr, x - 1, y, 1, 1);
+	cairo_rectangle (cr, x, y - 1, 1, 1);
+	cairo_fill (cr);
 }
 
 static void
@@ -240,8 +128,7 @@ mist_style_draw_hline(GtkStyle *style,
 	int i;
 	cairo_t *cr;
 
-	g_return_if_fail(style != NULL);
-	g_return_if_fail(window != NULL);
+	CHECK_ARGS
 	
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
@@ -310,8 +197,7 @@ mist_style_draw_vline(GtkStyle *style,
 	int i;
 	cairo_t *cr;
 
-	g_return_if_fail(style != NULL);
-	g_return_if_fail(window != NULL);
+	CHECK_ARGS
 	
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
@@ -378,27 +264,26 @@ mist_style_draw_shadow(GtkStyle *style,
 	MistStyle *mist_style = MIST_STYLE (style);
 	cairo_t *cr;
 
-	g_return_if_fail(style != NULL);
-	g_return_if_fail(window != NULL);
-	
+	CHECK_ARGS	
 	SANITIZE_SIZE
 
 	shadow_type = mist_get_shadow_type (style, detail, shadow_type);
 
+	if (shadow_type == GTK_SHADOW_NONE)
+		return;
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
-	if (state_type == GTK_STATE_INSENSITIVE && shadow_type != GTK_SHADOW_NONE) {
+	if (state_type == GTK_STATE_INSENSITIVE) {
 		shadow_type = GTK_SHADOW_ETCHED_IN;
 	}
 	
 	if (CHECK_DETAIL(detail, "frame") && widget && widget->parent && GE_IS_STATUSBAR (widget->parent)) {
-		if (shadow_type != GTK_SHADOW_NONE) {
-			ge_cairo_set_color(cr, &mist_style->color_cube.dark[GTK_STATE_NORMAL]);	
-	
-			cairo_move_to (cr, x + 0.5, y + 0.5);
-			cairo_line_to (cr, x + width - 0.5, y + 0.5);
-			cairo_stroke (cr);
-		}
+		ge_cairo_set_color(cr, &mist_style->color_cube.dark[GTK_STATE_NORMAL]);	
+
+		cairo_move_to (cr, x + 0.5, y + 0.5);
+		cairo_line_to (cr, x + width - 0.5, y + 0.5);
+		cairo_stroke (cr);
 	} else {
 		mist_draw_border (style, cr, state_type,
 				       shadow_type,x, y, width, height);
@@ -421,8 +306,8 @@ mist_style_draw_polygon(GtkStyle *style,
 {
 	MistStyle *mist_style = MIST_STYLE (style);
 
-	static const gdouble pi_over_4 = M_PI_4;
-	static const gdouble pi_3_over_4 = M_PI_4 * 3;
+	static const gdouble pi_over_4 = G_PI_4;
+	static const gdouble pi_3_over_4 = G_PI_4 * 3;
 	
 	CairoColor           *color1;
 	CairoColor           *color2;
@@ -434,8 +319,7 @@ mist_style_draw_polygon(GtkStyle *style,
 	int                i;
 	cairo_t           *cr;
 
-	g_return_if_fail(style != NULL);
-	g_return_if_fail(window != NULL);
+	CHECK_ARGS
 	g_return_if_fail(points != NULL);
 	
 	switch (shadow_type) {
@@ -543,9 +427,7 @@ mist_style_draw_diamond(GtkStyle * style,
 	int half_height;
 	cairo_t *cr;
 	
-	g_return_if_fail(style != NULL);
-	g_return_if_fail(window != NULL);	
-
+	CHECK_ARGS
 	SANITIZE_SIZE
 	
 	half_width = width / 2;
@@ -657,9 +539,7 @@ mist_style_draw_box(GtkStyle *style,
 	CairoColor *light, *dark;
 	cairo_t *cr;
 	
-	g_return_if_fail (style != NULL);
-	g_return_if_fail (window != NULL);
-
+	CHECK_ARGS
 	SANITIZE_SIZE
 
 	if (CHECK_DETAIL(detail, "menuitem") && state_type == GTK_STATE_PRELIGHT) {
@@ -683,8 +563,7 @@ mist_style_draw_box(GtkStyle *style,
 		cairo_fill(cr);
 
 		ge_cairo_set_color(cr, dark);	
-		cairo_rectangle(cr, x + 0.5, y + 0.5, width - 1, height - 1);
-		cairo_stroke(cr);
+		ge_cairo_stroke_rectangle(cr, x + 0.5, y + 0.5, width - 1, height - 1);
 	} else if (CHECK_DETAIL(detail, "menubar")
 		   || CHECK_DETAIL(detail, "dockitem_bin") 
 		   || CHECK_DETAIL(detail, "dockitem") 
@@ -713,8 +592,7 @@ mist_style_draw_box(GtkStyle *style,
 
 	} else if (CHECK_DETAIL(detail, "buttondefault")) {
 		ge_cairo_set_color(cr, &mist_style->color_cube.fg[GTK_STATE_NORMAL]);	
-		cairo_rectangle(cr, x + 0.5, y + 0.5, width - 1, height - 1);
-		cairo_stroke(cr);
+		ge_cairo_stroke_rectangle(cr, x + 0.5, y + 0.5, width - 1, height - 1);
 	} else {
 		/* Make sure stepper and slider outlines "overlap" - taken from
 		 * bluecurve */
@@ -788,8 +666,7 @@ mist_style_draw_check(GtkStyle *style,
 	cairo_fill(cr);
 
 	ge_cairo_set_color(cr, &mist_style->color_cube.dark[state_type]);	
-	cairo_rectangle(cr, x + 0.5, y + 0.5, width - 2, height - 2);
-	cairo_stroke(cr);
+	ge_cairo_stroke_rectangle(cr, x + 0.5, y + 0.5, width - 2, height - 2);
 	
 	if (shadow_type == GTK_SHADOW_IN) {
 		ge_cairo_set_color(cr, &mist_style->color_cube.base[GTK_STATE_SELECTED]);	
@@ -799,25 +676,27 @@ mist_style_draw_check(GtkStyle *style,
 #define gray50_width 2
 #define gray50_height 2
 		GdkBitmap *stipple;
+		GdkGC *gc = style->base_gc[GTK_STATE_SELECTED];
 		static const char gray50_bits[] = {
 			0x02, 0x01
 		};
-		
+
 		stipple = gdk_bitmap_create_from_data (window,
 						       gray50_bits, 
 						       gray50_width,
 						       gray50_height);
   
-		gdk_gc_set_fill (widget->style->base_gc[GTK_STATE_SELECTED],
-				 GDK_STIPPLED);
-		gdk_gc_set_stipple (widget->style->base_gc[GTK_STATE_SELECTED],
-				    stipple);
-		gdk_draw_rectangle(window,
-				   widget->style->base_gc[GTK_STATE_SELECTED],
-				   TRUE, x + 2, y + 2, width - 5, height - 5);
-		gdk_gc_set_fill (widget->style->base_gc[GTK_STATE_SELECTED],
-				 GDK_SOLID);
+		if (area)
+			gdk_gc_set_clip_rectangle (gc, area);
 
+		gdk_gc_set_fill (gc, GDK_STIPPLED);
+		gdk_gc_set_stipple (gc, stipple);
+		gdk_draw_rectangle(window, gc,
+				   TRUE, x + 2, y + 2, width - 5, height - 5);
+		gdk_gc_set_fill (gc, GDK_SOLID);
+
+		if (area)
+			gdk_gc_set_clip_rectangle (gc, NULL);
 #undef gray50_width
 #undef gray50_height 
 	}
@@ -845,15 +724,15 @@ mist_style_draw_option(GtkStyle *style,
 
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
-	cairo_arc(cr, x + floor(width/2), y + floor(height/2), floor(width/2) - 0.5, 0 , 2 * M_PI);
+	cairo_arc(cr, x + floor(width/2), y + floor(height/2), floor(width/2) - 0.5, 0 , 2 * G_PI);
 	ge_cairo_set_color(cr, &mist_style->color_cube.dark[state_type == GTK_STATE_INSENSITIVE ? GTK_STATE_INSENSITIVE : GTK_STATE_NORMAL]);	
 	cairo_stroke (cr);
 	
-	cairo_arc(cr, x + floor(width/2), y + floor(height/2), floor(width/2) - 0.5, 0 , 2 * M_PI);
+	cairo_arc(cr, x + floor(width/2), y + floor(height/2), floor(width/2) - 0.5, 0 , 2 * G_PI);
 	ge_cairo_set_color(cr, &mist_style->color_cube.base[state_type == GTK_STATE_INSENSITIVE ? GTK_STATE_INSENSITIVE : GTK_STATE_NORMAL]);	
 	cairo_fill (cr);
 
-	cairo_arc(cr, x + floor(width/2), y + floor(height/2), floor(width/2) - 0.5, 0 , 2 * M_PI);
+	cairo_arc(cr, x + floor(width/2), y + floor(height/2), floor(width/2) - 0.5, 0 , 2 * G_PI);
 	cairo_set_source_rgba(cr, 0, 0, 0, 0.35); 
 	cairo_stroke (cr);
 
@@ -882,7 +761,7 @@ mist_style_draw_option(GtkStyle *style,
 		else
 		{
 			ge_cairo_set_color(cr, &mist_style->color_cube.bg[GTK_STATE_SELECTED]);	
-			cairo_arc(cr, x + floor(width/2), y + floor(height/2), floor((width - 7)/2) + 1, 0 , 2 * M_PI);
+			cairo_arc(cr, x + floor(width/2), y + floor(height/2), floor((width - 7)/2) + 1, 0 , 2 * G_PI);
 			cairo_fill (cr);
 		}
 	}
@@ -911,6 +790,7 @@ mist_style_draw_shadow_gap(GtkStyle *style,
 	CairoColor *color1 = NULL;
 	CairoColor *color2 = NULL;
 	cairo_t *cr;
+	gint start;
 	
 	g_return_if_fail (window != NULL);
 	
@@ -921,6 +801,8 @@ mist_style_draw_shadow_gap(GtkStyle *style,
 
 	switch (shadow_type) {
 	case GTK_SHADOW_NONE:
+		/* need to destroy the cairo context. */
+		cairo_destroy (cr);
 		return;
 	case GTK_SHADOW_IN:
 		color1 = &mist_style->color_cube.dark[state_type];
@@ -936,96 +818,30 @@ mist_style_draw_shadow_gap(GtkStyle *style,
 		color2 = &mist_style->color_cube.dark[state_type];
 	}
 	
+	cairo_set_fill_rule (cr, CAIRO_FILL_RULE_EVEN_ODD);
+	cairo_rectangle (cr, x, y, width, height);
+	
 	switch (gap_side) {
         case GTK_POS_TOP:
-		if (gap_x > 0) {
-			ge_cairo_line (cr, color1, 
-				       x, y, 
-				       x + gap_x, y);
-		}
-		if ((width - (gap_x + gap_width)) > 0) {
-			ge_cairo_line (cr, color1, 
-				       x + gap_x + gap_width - 1, y,
-				       x + width - 1, y);
-		}
-		ge_cairo_line (cr, color1,
-			       x, y, 
-			       x, y + height - 1);
-		ge_cairo_line (cr, color2,
-			       x + width - 1, y,
-			       x + width - 1, y + height - 1);
-		ge_cairo_line (cr, color2,
-			       x, y + height - 1,
-			       x + width - 1, y + height - 1);
+        	start = MAX (1, gap_x + 1);
+        	cairo_rectangle (cr, x + start, y, MIN(width-1, gap_x+gap_width - 1) - start, 1);
 		break;
         case GTK_POS_BOTTOM:
-		ge_cairo_line (cr, color1,
-			       x, y,
-			       x + width - 1, y);
-		ge_cairo_line (cr, color1, 
-			       x, y, 
-			       x, y + height - 1);
-		ge_cairo_line (cr, color2,
-			       x + width - 1, y,
-			       x + width - 1, y + height - 1);
-
-		if (gap_x > 0) {
-			ge_cairo_line (cr, color2, 
-				       x, y + height - 1, 
-				       x + gap_x, y + height - 1);
-		}
-		if ((width - (gap_x + gap_width)) > 0) {
-			ge_cairo_line (cr, color2, 
-				       x + gap_x + gap_width - 1, y + height - 1,
-				       x + width - 1, y + height - 1);
-		}
-		
+        	start = MAX (1, gap_x + 1);
+        	cairo_rectangle (cr, x + start, y + height - 1, MIN(width-1, gap_x+gap_width - 1) - start, 1);
 		break;
         case GTK_POS_LEFT:
-		ge_cairo_line (cr, color1,
-			       x, y,
-			       x + width - 1, y);
-		if (gap_x > 0) {
-			ge_cairo_line (cr, color1, 
-				       x, y,
-				       x, y + gap_x);
-		}
-		if ((height - (gap_x + gap_width)) > 0) {
-			ge_cairo_line (cr, color1, 
-				       x, y + gap_x + gap_width - 1,
-				       x, y + height - 1);
-		}
-		ge_cairo_line (cr, color2,
-			       x + width - 1, y,
-			       x + width - 1, y + height - 1);
-		ge_cairo_line (cr, color2,
-			       x, y + height - 1,
-			       x + width - 1, y + height - 1);
+        	start = MAX (1, gap_x + 1);
+        	cairo_rectangle (cr, x, y + start, 1, MIN(width-1, gap_x+gap_width - 1) - start);
 		break;
         case GTK_POS_RIGHT:
-		ge_cairo_line (cr, color1,
-			       x, y,
-			       x + width - 1, y);
-		ge_cairo_line (cr, color1, 
-			       x, y, 
-			       x, y + height - 1);
-
-
-		if (gap_x > 0) {
-			ge_cairo_line (cr, color2, 
-				       x + width - 1, y,
-				       x + width - 1, y + gap_x);
-		}
-		if ((height - (gap_x + gap_width)) > 0) {
-			ge_cairo_line (cr, color2, 
-				       x + width - 1, y + gap_x + gap_width - 1,
-				       x + width - 1, y + height - 1);
-		}
-		ge_cairo_line (cr, color2,
-			       x, y + height - 1,
-			       x + width - 1, y + height - 1);
-
+        	start = MAX (1, gap_x + 1);
+        	cairo_rectangle (cr, x + width - 1, y + start, 1, MIN(width-1, gap_x+gap_width - 1) - start);
+        	break;
 	}
+	cairo_clip (cr);
+	cairo_new_path (cr);
+	ge_cairo_simple_border (cr, color1, color2, x, y, width, height, FALSE);
 	
 	cairo_destroy(cr);
 }
@@ -1072,47 +888,54 @@ mist_style_draw_extension(GtkStyle *style,
                int height,
                GtkPositionType gap_side)
 {
-	GdkRectangle        rect;
-	
-	g_return_if_fail(style != NULL);
-	g_return_if_fail(window != NULL);
-	
+	cairo_t *canvas;
+	CairoColor *background, *light, *dark;
+
+	CHECK_ARGS
 	SANITIZE_SIZE
 
-	mist_tab(style, window, state_type, shadow_type, area,
-		 widget, detail, x, y, width, height, gap_side);
+
+	background = &MIST_STYLE(style)->color_cube.bg[state_type];
+	light = &MIST_STYLE(style)->color_cube.light[state_type];
+	dark = &MIST_STYLE(style)->color_cube.dark[state_type];
 	
-	switch (gap_side) {
-	case GTK_POS_TOP:
-		rect.x = x + XTHICKNESS(style);
-		rect.y = y;
-		rect.width = width - XTHICKNESS(style) * 2;
-		rect.height = YTHICKNESS(style);
-		break;
-	case GTK_POS_LEFT:
-		rect.x = x;
-		rect.y = y + YTHICKNESS(style);
-		rect.width = XTHICKNESS(style);
-		rect.height = height - YTHICKNESS(style) * 2;
-		break;
-	case GTK_POS_RIGHT:
-		rect.x = x + width - XTHICKNESS(style);
-		rect.y = y + YTHICKNESS(style);
-		rect.width = XTHICKNESS(style);
-		rect.height = height - YTHICKNESS(style) * 2;
-		break;
-	default:
-	case GTK_POS_BOTTOM:
-		rect.x = x + XTHICKNESS(style);
-		rect.y = y + height - YTHICKNESS(style);
-		rect.width = width - XTHICKNESS(style) * 2;
-		rect.height = YTHICKNESS(style);
-		break;
+	canvas = ge_gdk_drawable_to_cairo (window, area);
+
+	if ((!style->bg_pixmap[state_type]) || GDK_IS_PIXMAP(window)) 
+	{
+		ge_cairo_set_color(canvas, background);	
+
+		cairo_rectangle(canvas, x, y, width, height);
+		cairo_fill(canvas);
+	} else {
+		gtk_style_apply_default_background
+			(style, window,
+			 widget && !GTK_WIDGET_NO_WINDOW(widget),
+			 state_type, area, x, y, width, height);
 	}
 	
-	gtk_style_apply_default_background(style, window,
-					   widget && !GTK_WIDGET_NO_WINDOW(widget),
-					   state_type, area, rect.x, rect.y, rect.width, rect.height);
+	cairo_rectangle (canvas, x, y, width, height);
+	cairo_clip (canvas);
+	
+	switch(gap_side) {
+	case GTK_POS_BOTTOM:
+		height++;
+		break;
+	case GTK_POS_TOP:
+		y--;
+		height++;
+		break;
+	case GTK_POS_RIGHT:
+		width++;
+		break;
+	case GTK_POS_LEFT:
+		x--;
+		width++;
+		break;
+	}
+
+	ge_cairo_simple_border (canvas, light, dark, x, y, width, height, FALSE);
+	cairo_destroy(canvas);
 }
 
 static void
@@ -1136,13 +959,12 @@ mist_style_draw_handle(GtkStyle *style,
 	int modx, mody;
 	cairo_t *cr;
 	
-	g_return_if_fail(style != NULL);
-	g_return_if_fail(window != NULL);
-	
+	CHECK_ARGS
 	SANITIZE_SIZE
 
-	gtk_paint_box(style, window, state_type, shadow_type, area, widget,
-		      detail, x, y, width, height);
+	if (!ge_is_panel_widget_item (widget) && !ge_object_is_a ((GObject*)widget, "PanelToplevel"))
+		gtk_paint_box(style, window, state_type, shadow_type, area, widget,
+			      detail, x, y, width, height);
 	
 	light = &mist_style->color_cube.light[state_type];
 	dark = &mist_style->color_cube.dark[state_type];
@@ -1203,9 +1025,7 @@ mist_style_draw_resize_grip(GtkStyle *style,
 	int threshold;
 	cairo_t *cr;
 	
-	g_return_if_fail(style != NULL);
-	g_return_if_fail(window != NULL);
-	
+	CHECK_ARGS
 	SANITIZE_SIZE
 	
 	switch (edge) {
@@ -1318,8 +1138,8 @@ mist_style_draw_resize_grip(GtkStyle *style,
 			if (draw_dot) {
 				mist_dot(cr,
 					 light, dark,
-					 x + (xi * 5) + 2,
-					 y + (yi * 5) + 2);
+					 x + (xi * 5) + 1,
+					 y + (yi * 5) + 1);
 			}
 		}
 	}
@@ -1338,8 +1158,7 @@ mist_style_draw_string (GtkStyle      *style,
 	     int            y,
 	     const char    *string)
 {
-	g_return_if_fail (GTK_IS_STYLE (style));
-	g_return_if_fail (window != NULL);
+	CHECK_ARGS
 	
 	if (area) {
 		gdk_gc_set_clip_rectangle (style->fg_gc[state_type], area);
@@ -1368,8 +1187,7 @@ mist_style_draw_layout (GtkStyle        *style,
 {
 	GdkGC *gc;
 	
-	g_return_if_fail (GTK_IS_STYLE (style));
-	g_return_if_fail (window != NULL);
+	CHECK_ARGS
 	
 	gc = use_text ? style->text_gc[state_type] : style->fg_gc[state_type];
 	
