@@ -23,196 +23,93 @@
 #include "redmond_gtk2_drawing.h"
 #include "redmond_gtk2_misc.h"
  
-static char radio_base_bits[] = {
-  0x00,0x00,0x00,0x00,0xf0,0x01,0xf8,0x03,0xfc,0x07,0xfc,0x07,0xfc,0x07,0xfc,
-  0x07,0xfc,0x07,0xf8,0x03,0xf0,0x01,0x00,0x00,0x00,0x00,0x00,0x00};
-static char radio_black_bits[] = {
-  0x00,0x00,0xf0,0x01,0x0c,0x02,0x04,0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
-  0x00,0x02,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0x08};
-static char radio_dark_bits[] = {
-  0xf0,0x00,0x0c,0x02,0x02,0x00,0x02,0x00,0x01,0x00,0x01,0x00,0x01,0x00,0x01,
-  0x00,0x00,0x00,0x02,0x00,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00};
-static char radio_light_bits[] = {
-  0x00,0x00,0x00,0x04,0x00,0x08,0x00,0x08,0x00,0x10,0x00,0x10,0x00,0x10,0x00,
-  0x10,0x00,0x10,0x00,0x08,0x00,0x08,0x08,0x06,0xf0,0x01,0x00,0x00};
-static char radio_mid_bits[] = {
-  0x00,0x00,0x00,0x00,0x00,0x04,0x00,0x04,0x00,0x08,0x00,0x08,0x00,0x08,0x00,
-  0x08,0x00,0x08,0x00,0x04,0x00,0x06,0xf0,0x01,0x00,0x00,0x00,0x00};
-static char radio_text_bits[] = {
-  0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe0,0x00,0xf0,0x01,0xf0,0x01,0xf0,
-  0x01,0xe0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};
- 
-static struct
-{
-  char *bits;
-  GdkBitmap *bmap;
-} parts[] =
-{
-  {
-  radio_base_bits, NULL},
-  {
-  radio_black_bits, NULL},
-  {
-  radio_dark_bits, NULL},
-  {
-  radio_light_bits, NULL},
-  {
-  radio_mid_bits, NULL},
-  {
-  radio_text_bits, NULL}
-};
- 
-/***********************************************
- * redmond_draw_part -
- *  
- *   draw a bits generated pixmap part with a
- *   specific gc.
- ***********************************************/
 void
-redmond_draw_part (GdkDrawable * drawable,
-	   GdkGC * gc, 
-           GdkRectangle * area, 
-           gint x, 
-           gint y, 
-           Part part)
-{
-  if (area)
-    gdk_gc_set_clip_rectangle (gc, area);
- 
-  if (!parts[part].bmap)
-    parts[part].bmap = gdk_bitmap_create_from_data (drawable,
-						    parts[part].bits,
-						    PART_SIZE, PART_SIZE);
- 
-  gdk_gc_set_ts_origin (gc, x, y);
-  gdk_gc_set_stipple (gc, parts[part].bmap);
-  gdk_gc_set_fill (gc, GDK_STIPPLED);
- 
-  gdk_draw_rectangle (drawable, gc, TRUE, x, y, PART_SIZE, PART_SIZE);
- 
-  gdk_gc_set_fill (gc, GDK_SOLID);
- 
-  if (area)
-    gdk_gc_set_clip_rectangle (gc, NULL);
-}
- 
-/***********************************************
- * do_redmond_draw_fill -
- *  
- *   A simple routine to fill with the bg_gc
- ***********************************************/
-void
-do_redmond_draw_default_fill (GtkStyle *style, 
-                              GdkWindow *window, 
-                              GtkStateType state_type, 
-                              GdkRectangle *area, 
-                              gint x, 
-                              gint y, 
-                              gint width, 
-                              gint height)
-{
-      if (area)
-        gdk_gc_set_clip_rectangle(style->bg_gc[state_type], area);
-        
-      gdk_draw_rectangle (window, style->bg_gc[state_type], TRUE,
-                          x, y,width, height);
- 
-      if (area)
-        gdk_gc_set_clip_rectangle(style->bg_gc[state_type], NULL);
-}
- 
-/***********************************************
- * do_redmond_draw_cross_hatch_fill -
- *  
- *   A simple routine to draw a thin cross-hatch 
- *   background fill. This is use for Scrollbar
- *   Trough's and greyed Checkbox's
- *    
- *   It originated in Smooth-Engine.
- ***********************************************/
-void
-do_redmond_draw_cross_hatch_fill (GtkStyle * style,
-                                  GdkWindow * window,
-                                  GtkStateType state,
-                                  GdkRectangle * area,
-                                  Part part,
+do_redmond_draw_masked_fill (cairo_t * cr,
+                                  CairoPattern *mask,
+                                  CairoColor * background,
+                                  CairoColor * foreground,
                                   gint x,
                                   gint y, 
                                   gint width, 
                                   gint height)
 {
-  GdkGCValues gc_values;
-  GdkGC *gc;
-  GdkPixmap *pixmap;
- 
-  pixmap = gdk_pixmap_new (window, 2, 2, -1);
- 
-  gdk_draw_point (pixmap, style->bg_gc[state], 0, 0);
-  gdk_draw_point (pixmap, style->bg_gc[state], 1, 1);
-  gdk_draw_point (pixmap, style->light_gc[state], 1, 0);
-  gdk_draw_point (pixmap, style->light_gc[state], 0, 1);
- 
-  gc_values.fill = GDK_TILED;
-  gc_values.tile = pixmap;
-  gc_values.ts_x_origin = x;
-  gc_values.ts_y_origin = y;
-  gc = gdk_gc_new_with_values (window, &gc_values,
-                               GDK_GC_TS_X_ORIGIN | GDK_GC_TS_Y_ORIGIN |
-                               GDK_GC_FILL | GDK_GC_TILE);
- 
-  if (part != RADIO_NONE)
-  {
-    if (!parts[part].bmap)
-      parts[part].bmap = gdk_bitmap_create_from_data (window,
-  						      parts[part].bits,
- 						      PART_SIZE, PART_SIZE);
-    gdk_gc_set_clip_origin (gc, x, y);	
-    gdk_gc_set_clip_mask(gc, parts[part].bmap);
-  }
-  else if (area)
-    gdk_gc_set_clip_rectangle (gc, area);
- 
-  gdk_draw_rectangle (window, gc, TRUE, x, y, width, height);
- 
-  g_object_unref (gc);
-  g_object_unref (pixmap);
+	ge_cairo_set_color(cr, background);
+	cairo_rectangle (cr, x, y, width, height);
+	cairo_fill(cr);
+
+	ge_cairo_set_color(cr, foreground);
+	cairo_rectangle (cr, x, y, width, height);
+	cairo_mask (cr, mask->handle);
 }
   
 /***********************************************
  * do_redmond_draw_check -
  *  
  *   A simple routine to draw a redmond style
- *   check mark using the passed GC.
+ *   check mark using the passed Color.
  *  
  *   It originated in Smooth-Engine.
  ***********************************************/
 void
-do_redmond_draw_check (cairo_t *cr,
+do_redmond_draw_check (cairo_t *canvas,
                        CairoColor * color,
                        gint x, 
                        gint y, 
                        gint width, 
                        gint height)
 { 
-  double left, top;
-  int scale;
+  gint odd = 0;
+  gdouble left, top;
+  gint scale, factor;
 
   scale = MIN(width, height);
 
-  if (!(scale % 2))
-    scale -= 1;
+  factor = 10;
 
-  if (scale <= 11)
-    scale = 9;
+  if ((odd = (scale % 2)))
+  {
+    factor -= 1;
+  }
+
+  if (scale <= (factor + 2))
+    scale = factor;
 
   left = x + floor((width - scale) / 2) + 0.5;
   top = y + floor((height - scale) / 2) + 0.5;
 
-  cairo_save(cr);
+  cairo_save(canvas);
 
-  ge_cairo_set_color(cr, color);	
-  cairo_set_line_width(cr, 0.5);
+  ge_cairo_set_color(canvas, color);	
+  cairo_set_line_width(canvas, 0.5);
 /*
+
+EVEN - 
+
+    0   1   2   3   4   5   6   7   8   9
+  +---+---+---+---+---+---+---+---+---+---+
+0 |   |   |   |   |   |   |   |   |   |   |
+  +---+---+---+---+---+---+---+---+---+---+
+1 |   |   |   |   |   |   |   |   | x |   |
+  +---+---+---+---+---+---+---+---+---+---+
+2 |   |   |   |   |   |   |   | x | x |   |
+  +---+---+---+---+---+---+---+---+---+---+
+3 |   |   |   |   |   |   | x | x | x |   |
+  +---+---+---+---+---+---+---+---+---+---+
+4 |   | x |   |   |   | x | x | x |   |   |
+  +---+---+---+---+---+---+---+---+---+---+
+5 |   | x | x |   | x | x | x |   |   |   |
+  +---+---+---+---+---+---+---+---+---+---+
+6 |   | x | x | x | x | x |   |   |   |   |
+  +---+---+---+---+---+---+---+---+---+---+
+7 |   |   | x | x | x |   |   |   |   |   |
+  +---+---+---+---+---+---+---+---+---+---+
+8 |   |   |   | x |   |   |   |   |   |   |
+  +---+---+---+---+---+---+---+---+---+---+
+9 |   |   |   |   |   |   |   |   |   |   |
+  +---+---+---+---+---+---+---+---+---+---+
+
+ODD -
+
     0   1   2   3   4   5   6   7   8
   +---+---+---+---+---+---+---+---+---+
 0 |   |   |   |   |   |   |   |   |   |
@@ -236,26 +133,19 @@ do_redmond_draw_check (cairo_t *cr,
 
 */
 
-  cairo_move_to(cr, left + floor((1*scale)/9), top + floor((3*scale)/9)); //(1,3)
-  cairo_line_to(cr, left + floor((1*scale)/9), top + floor((5*scale)/9)); //(1,5)
-  cairo_line_to(cr, left + floor((3*scale)/9), top + floor((7*scale)/9)); //(3,7)
-  cairo_line_to(cr, left + floor((7*scale)/9), top + floor((3*scale)/9)); //(7,3)
-  cairo_line_to(cr, left + floor((7*scale)/9), top + floor((1*scale)/9)); //(7,1)
-  cairo_line_to(cr, left + floor((3*scale)/9), top + floor((5*scale)/9)); //(3,5)
-  cairo_line_to(cr, left + floor((1*scale)/9), top + floor((3*scale)/9)); //(1,3)
+  cairo_move_to(canvas, left + floor((1*scale)/factor), top + floor(((4-odd)*scale)/factor)); /*(1,4-odd)*/
+  cairo_line_to(canvas, left + floor((1*scale)/factor), top + floor(((6-odd)*scale)/factor)); /*(1,6-odd)*/
+  cairo_line_to(canvas, left + floor((3*scale)/factor), top + floor(((8-odd)*scale)/factor)); /*(3,8-odd)*/
+  cairo_line_to(canvas, left + floor(((8-odd)*scale)/factor), top + floor((3*scale)/factor)); /*(8-odd,3)*/
+  cairo_line_to(canvas, left + floor(((8-odd)*scale)/factor), top + floor((1*scale)/factor)); /*(8-odd,1)*/
+  cairo_line_to(canvas, left + floor((3*scale)/factor), top + floor(((6-odd)*scale)/factor)); /*(3,6-odd)*/
+  cairo_line_to(canvas, left + floor((1*scale)/factor), top + floor(((4-odd)*scale)/factor)); /*(1,4-odd)*/
 
-  cairo_fill(cr);
+  cairo_fill_preserve(canvas);
 
-  cairo_move_to(cr, left + floor((1*scale)/9), top + floor((3*scale)/9)); //(1,3)
-  cairo_line_to(cr, left + floor((1*scale)/9), top + floor((5*scale)/9)); //(1,5)
-  cairo_line_to(cr, left + floor((3*scale)/9), top + floor((7*scale)/9)); //(3,7)
-  cairo_line_to(cr, left + floor((7*scale)/9), top + floor((3*scale)/9)); //(7,3)
-  cairo_line_to(cr, left + floor((7*scale)/9), top + floor((1*scale)/9)); //(7,1)
-  cairo_line_to(cr, left + floor((3*scale)/9), top + floor((5*scale)/9)); //(3,5)
-  cairo_line_to(cr, left + floor((1*scale)/9), top + floor((3*scale)/9)); //(1,3)
-  cairo_stroke(cr);
+  cairo_stroke(canvas);
 
-  cairo_restore(cr);
+  cairo_restore(canvas);
 }
  
 /***********************************************
@@ -269,154 +159,181 @@ do_redmond_draw_check (cairo_t *cr,
  *   both which  were based on ThinIce's.
  ***********************************************/
 void
-do_redmond_draw_arrow (cairo_t *cr,
+do_redmond_draw_arrow (cairo_t *canvas,
                CairoColor * color,
                GtkArrowType arrow_type,
+               gboolean fill,
                gint x, 
                gint y, 
                gint width, 
                gint height)
 {
-  gint i;
- 
-  gint steps, extra;
-  gint start, increment;
-  gint aw = width, ah = height;
- 	
-  if ((arrow_type == GTK_ARROW_UP) || (arrow_type == GTK_ARROW_DOWN))
-    {
-      gdouble tmp=((aw+1)/2) - ((height%2)?1:0);
+	gint aw = width, ah = height;
+ 	GdkPoint points[3];
+
+	switch (arrow_type)
+	{
+		case GTK_ARROW_UP:
+		case GTK_ARROW_DOWN:
+		{
+			gdouble tmp=((aw+1)/2) - ((height%2)?1:0);
        
-      if (tmp > ah) 
-        {
-          aw = 2*ah - 1 - ((height%2)?1:0);
-          ah = (aw+1)/2;
-        } 
-      else 
-        {
-          ah = (gint) tmp;
-          aw = 2*ah - 1;
-        }  
+			if (tmp > ah) 
+			{
+				aw = 2*ah - 1 - ((height%2)?1:0);
+				ah = (aw+1)/2;
+			} 
+			else 
+			{
+				ah = (gint) tmp;
+				aw = 2*ah - 1;
+			}  
  
-      if ((aw < 5) || (ah < 3)) 
-        {
-          aw = 5;
-          ah = 3;
-        }
+			if ((aw < 5) || (ah < 3)) 
+			{
+				aw = 5;
+				ah = 3;
+			}
  
-      x += (width - aw) / 2 ;
-      y += (height - ah) / 2;
-      width = aw;
-      height = ah;
+			x += (width - aw) / 2 ;
+			y += (height - ah) / 2;
+			width = aw;
+			height = ah;
  		
-      width += width % 2 - 1;
+			width += width % 2 - 1;
+
+			points[0].x = x;
+			points[1].x = x + width - 1;
+			points[2].x = x + ((height - 1) - (height - (1 + width / 2)));
+
+			points[0].y = points[1].y = y;
+			points[2].y = y + height - 1;
+
+			if (arrow_type == GTK_ARROW_UP)
+			{
+				gint flip = points[1].y;
+
+				points[0].y = points[1].y = points[2].y;
+				points[2].y = flip;
+			}
+		}
+		break;
+
+		case GTK_ARROW_LEFT:
+		case GTK_ARROW_RIGHT:
+		{
+			gdouble tmp=((ah+1)/2) - ((width%2)?1:0);
  
-      steps = 1 + width / 2;
-      extra = height - steps;
+			if (tmp > aw) 
+			{
+				ah = 2*aw - 1 - ((width%2)?1:0);
+				aw = (ah+1)/2;
+			} 
+			else 
+			{
+				aw = (gint) tmp;
+				ah = 2*aw - 1;
+			}  
  
-      if (arrow_type == GTK_ARROW_DOWN)
-        {
-          start = y;
-          increment = 1;
-        }
-      else
-        {
-          start = y + height - 1;
-          increment = -1;
-        }
+			if ((ah < 5) || (aw < 3)) 
+			{
+				ah = 5;
+				aw = 3;
+			}
  
-      cairo_save(cr);
-
-      ge_cairo_set_color(cr, color);	
-      cairo_set_line_width (cr, 0.5);
-
-      cairo_move_to(cr, x + 0.5, start + 0.5);
-      cairo_line_to(cr, x + width - 0.5, start + 0.5);
-      cairo_line_to(cr, x + ((height - 1) - extra) + 0.5, start + (height - 1)*increment + 0.5);
-      cairo_line_to(cr, x + 0.5, start + 0.5);
-
-      cairo_stroke(cr);
-
-
-      cairo_move_to(cr, x + 0.5, start + 0.5);
-      cairo_line_to(cr, x + width - 0.5, start + 0.5);
-      cairo_line_to(cr, x + ((height - 1) - extra) + 0.5, start + (height - 1)*increment + 0.5);
-      cairo_line_to(cr, x + 0.5, start + 0.5);
-
-      cairo_fill(cr);
-
-      cairo_restore(cr);
-    }
-  else
-    {
-      gdouble tmp=((ah+1)/2) - ((width%2)?1:0);
+			x += (width - aw) / 2 ;
+			y += (height - ah) / 2;
+			width = aw;
+			height = ah;
  
-      if (tmp > aw) 
-        {
-          ah = 2*aw - 1 - ((width%2)?1:0);
-          aw = (ah+1)/2;
-        } 
-      else 
-        {
-          aw = (gint) tmp;
-          ah = 2*aw - 1;
-        }  
- 
-      if ((ah < 5) || (aw < 3)) 
-        {
-          ah = 5;
-          aw = 3;
-        }
- 
-      x += (width - aw) / 2 ;
-      y += (height - ah) / 2;
-      width = aw;
-      height = ah;
- 
-      height += height % 2 - 1;
- 
-      steps = 1 + height / 2;
-      extra = width - steps;
- 
-      if (arrow_type == GTK_ARROW_RIGHT)
-        {
-          start = x;
-          increment = 1;
-        }
-      else
-        {
-          start = x + width - 1;
-          increment = -1;
-        }
- 
-      cairo_save(cr);
+			height += height % 2 - 1;
 
-      ge_cairo_set_color(cr, color);	
-      cairo_set_line_width (cr, 0.5);
+			points[0].y = y;
+			points[1].y = y + height - 1;
+			points[2].y = y + ((width - 1) - (width - (1 + height / 2)));
 
-      cairo_move_to(cr, start + 0.5, y + 0.5);
-      cairo_line_to(cr, start + 0.5, y + height - 0.5);
-      cairo_line_to(cr, start + (width - 1)*increment + 0.5, y + ((width - 1) - extra) + 0.5);
-      cairo_line_to(cr, start + 0.5, y + 0.5);
+			points[0].x = points[1].x = x;
+			points[2].x = x + width - 1;
 
-      cairo_stroke(cr);
+			if (arrow_type == GTK_ARROW_LEFT)
+			{
+				gint flip = points[0].x;
 
+				points[0].x = points[1].x = points[2].x;
+				points[2].x = flip;
+			}
+		}
+		break;
 
-      cairo_move_to(cr, start + 0.5, y + 0.5);
-      cairo_line_to(cr, start + 0.5, y + height - 0.5);
-      cairo_line_to(cr, start + (width - 1)*increment + 0.5, y + ((width - 1) - extra) + 0.5);
-      cairo_line_to(cr, start + 0.5, y + 0.5);
+		default:
+		{
+			return;
+		}
+	}
 
-      cairo_fill(cr);
+	cairo_save(canvas);
 
-      cairo_restore(cr);
-    }
+	ge_cairo_set_color(canvas, color);	
+	cairo_set_line_width (canvas, 0.5);
+
+	cairo_move_to(canvas, points[0].x + 0.5, points[0].y + 0.5);
+	cairo_line_to(canvas, points[1].x + 0.5, points[1].y + 0.5);
+	cairo_line_to(canvas, points[2].x + 0.5, points[2].y + 0.5);
+	cairo_line_to(canvas, points[0].x + 0.5, points[0].y + 0.5);
+
+	if (fill)
+	{
+		cairo_stroke_preserve(canvas);
+
+		cairo_fill(canvas);
+	}
+	else
+	{
+		cairo_stroke(canvas);
+	}
+
+	cairo_restore(canvas);
 }
  
-/***********************************************/
-/* MenuShell/MenuBar Item Prelight Workaround  */
-/***********************************************/
- 
+void
+do_redmond_draw_simple_circle (cairo_t *canvas,
+                     	  		CairoColor * tl,
+                       			CairoColor * br,
+					gint center_x, 
+					gint center_y, 
+					gint radius)
+{ 
+      cairo_save(canvas);
+
+      cairo_move_to(canvas, center_x + (radius + 2), center_y + (radius + 2));
+      cairo_line_to(canvas, center_x + (radius + 2)*sin(G_PI/4.0), center_y - (radius + 2)*cos(G_PI/4.0));
+      cairo_line_to(canvas, center_x - (radius + 2)*sin(G_PI/4.0), center_y + (radius + 2)*cos(G_PI/4.0));
+      cairo_line_to(canvas, center_x + (radius + 2), center_y + (radius + 2));
+
+      cairo_clip (canvas);
+
+      ge_cairo_set_color(canvas, br);
+      cairo_arc(canvas, center_x, center_y, radius, 0,  2*G_PI);
+      cairo_fill(canvas);
+
+      cairo_restore(canvas);
+
+      cairo_save(canvas);
+
+      cairo_move_to(canvas, center_x - (radius + 2), center_y - (radius + 2));
+      cairo_line_to(canvas, center_x + (radius + 2)*sin(G_PI/4.0), center_y - (radius + 2)*cos(G_PI/4.0));
+      cairo_line_to(canvas, center_x - (radius + 2)*sin(G_PI/4.0), center_y + (radius + 2)*cos(G_PI/4.0));
+      cairo_line_to(canvas, center_x - (radius + 2), center_y - (radius + 2));
+
+      cairo_clip (canvas);
+
+      ge_cairo_set_color(canvas, tl); 
+      cairo_arc(canvas, center_x, center_y, radius, 0, 2*G_PI);
+      cairo_fill(canvas);
+
+      cairo_restore(canvas);
+}
+
 /***********************************************
  * do_redmond_draw_line -
  *  
@@ -461,50 +378,54 @@ do_redmond_draw_line(cairo_t *cr,
     }
 }
  
+/***********************************************/
+/* MenuShell/MenuBar Item Prelight Workaround  */
+/***********************************************/
+ 
 /***********************************************
- * gtk_menu_shell_style_set -
+ * redmond_gtk2_engine_hack_menu_shell_style_set -
  *  
  *   Style set signal to ensure menushell signals
  *   get cleaned up if the theme changes
  ***********************************************/
 static gboolean 
-gtk_menu_shell_style_set(GtkWidget *widget,
+redmond_gtk2_engine_hack_menu_shell_style_set(GtkWidget *widget,
                          GtkStyle *previous_style,
                          gpointer user_data)
 {
-  gtk_menu_shell_cleanup_signals(widget);
+  redmond_gtk2_engine_hack_menu_shell_cleanup_signals(widget);
   
   return FALSE;
 }
  
 /***********************************************
- * gtk_menu_shell_destroy -
+ * redmond_gtk2_engine_hack_menu_shell_destroy -
  *  
  *   Destroy signal to ensure menushell signals
  *   get cleaned if it is destroyed
  ***********************************************/
 static gboolean    
-gtk_menu_shell_destroy(GtkWidget *widget,
+redmond_gtk2_engine_hack_menu_shell_destroy(GtkWidget *widget,
                        GdkEvent *event,
                        gpointer user_data)
 {
-  gtk_menu_shell_cleanup_signals(widget);
+  redmond_gtk2_engine_hack_menu_shell_cleanup_signals(widget);
   
   return FALSE;
 }
  
 /***********************************************
- * gtk_menu_shell_motion -
+ * redmond_gtk2_engine_hack_menu_shell_motion -
  *  
  *   Motion signal to ensure menushell items
  *   prelight state changes on mouse move.
  ***********************************************/
 static gboolean 
-gtk_menu_shell_motion(GtkWidget *widget, 
+redmond_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget, 
                       GdkEventMotion *event, 
                       gpointer user_data)
 {
-  if (IS_MENU_SHELL(widget))
+  if (GE_IS_MENU_SHELL(widget))
     {
       gint pointer_x, pointer_y;
       GdkModifierType pointer_mask;
@@ -512,13 +433,13 @@ gtk_menu_shell_motion(GtkWidget *widget,
      
       gdk_window_get_pointer(widget->window, &pointer_x, &pointer_y, &pointer_mask);
 	    
-      if (IS_CONTAINER(widget))
+      if (GE_IS_CONTAINER(widget))
         {
           children = gtk_container_get_children(GTK_CONTAINER(widget));
               
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
-	      if ((child->data) && IS_WIDGET(child->data) && 
+	      if ((child->data) && GE_IS_WIDGET(child->data) && 
                   (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
 	          if ((pointer_x >= GTK_WIDGET(child->data)->allocation.x) && 
@@ -546,30 +467,30 @@ gtk_menu_shell_motion(GtkWidget *widget,
 }
  
 /***********************************************
- * gtk_menu_shell_leave -
+ * redmond_gtk2_engine_hack_menu_shell_leave -
  *  
  *   Leave signal to ensure menushell items
  *   normal state on mouse leave.
  ***********************************************/
 static gboolean 
-gtk_menu_shell_leave(GtkWidget *widget, 
+redmond_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget, 
                       GdkEventCrossing *event,
                       gpointer user_data)
 {
-  if (IS_MENU_SHELL(widget))
+  if (GE_IS_MENU_SHELL(widget))
     {
       GList *children = NULL, *child = NULL;
  
-      if (IS_CONTAINER(widget))
+      if (GE_IS_CONTAINER(widget))
         {
           children = gtk_container_get_children(GTK_CONTAINER(widget));
               
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
-	      if ((child->data) && IS_MENU_ITEM(child->data) && 
+	      if ((child->data) && GE_IS_MENU_ITEM(child->data) && 
                   (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
-                  if ((!GTK_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
+                  if ((!GE_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
                       (!(GTK_WIDGET_REALIZED(GTK_MENU_ITEM(child->data)->submenu) && 
                          GTK_WIDGET_VISIBLE(GTK_MENU_ITEM(child->data)->submenu) &&
                          GTK_WIDGET_REALIZED(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel) &&
@@ -589,40 +510,40 @@ gtk_menu_shell_leave(GtkWidget *widget,
 }
  
 /***********************************************
- * gtk_menu_shell_setup_signals -
+ * redmond_gtk2_engine_menu_shell_setup_signals -
  *  
  *   Setup Menu Shell with signals to ensure
  *   prelight works on items
  ***********************************************/
 void
-gtk_menu_shell_setup_signals(GtkWidget *widget)
+redmond_gtk2_engine_hack_menu_shell_setup_signals(GtkWidget *widget)
 {
-  if (IS_MENU_BAR(widget))
+  if (GE_IS_MENU_BAR(widget))
     {
       gint id = 0;
  
       if (!g_object_get_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_HACK_SET"))
       {
         id = g_signal_connect(G_OBJECT(widget), "motion-notify-event",
-                                             (GtkSignalFunc)gtk_menu_shell_motion,
+                                             (GtkSignalFunc)redmond_gtk2_engine_hack_menu_shell_motion,
                                              NULL);
                                   
         g_object_set_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_MOTION_ID", (gpointer)id);
         
         id = g_signal_connect(G_OBJECT(widget), "leave-notify-event",
-                                             (GtkSignalFunc)gtk_menu_shell_leave,
+                                             (GtkSignalFunc)redmond_gtk2_engine_hack_menu_shell_leave,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_LEAVE_ID", (gpointer)id);
                                              
         id = g_signal_connect(G_OBJECT(widget), "destroy-event",
-                                             (GtkSignalFunc)gtk_menu_shell_destroy,
+                                             (GtkSignalFunc)redmond_gtk2_engine_hack_menu_shell_destroy,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_DESTROY_ID", (gpointer)id);
  
         g_object_set_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_HACK_SET", (gpointer)1);
         
         id = g_signal_connect(G_OBJECT(widget), "style-set",
-                                             (GtkSignalFunc)gtk_menu_shell_style_set,
+                                             (GtkSignalFunc)redmond_gtk2_engine_hack_menu_shell_style_set,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_STYLE_SET_ID", (gpointer)id);
       }
@@ -630,14 +551,14 @@ gtk_menu_shell_setup_signals(GtkWidget *widget)
 }
  
 /***********************************************
- * gtk_menu_shell_cleanuo_signals -
+ * redmond_gtk2_engine_hack_menu_shell_cleanuo_signals -
  *  
  *   Cleanup/remove Menu Shell signals
  ***********************************************/
 void
-gtk_menu_shell_cleanup_signals(GtkWidget *widget)
+redmond_gtk2_engine_hack_menu_shell_cleanup_signals(GtkWidget *widget)
 {
-  if (IS_MENU_BAR(widget))
+  if (GE_IS_MENU_BAR(widget))
     {
       gint id = 0;
  
